@@ -2,6 +2,7 @@ import logging
 import os
 import random
 import re
+import shutil
 import string
 import warnings
 
@@ -20,10 +21,13 @@ class SynologyFileCache():
         self.port = port
         self.username = username
         self.password = password
+        self.fl = None
 
     def getFl(self):
-        return filestation.FileStation(ip_address=self.ip_address, port=self.port, username=self.username,
-                                       password=self.password)
+        if self.fl == None:
+            self.fl = filestation.FileStation(ip_address=self.ip_address, port=self.port, username=self.username,
+                                              password=self.password)
+        return self.fl
 
     def random_str(self, num):
         salt = ''.join(random.sample(string.ascii_letters + string.digits, num))
@@ -56,31 +60,44 @@ class SynologyFileCache():
         @param file_path: 文件路径 url|本地目录|本地文件
         @param del_local: 缓存后是否删除本地文件
         """
+        if not os.path.exists(file_path) and not re.match("http", file_path):
+            raise FileNotFoundError(file_path)
+
         local_path = '/tmp/%s.%s/%s' % (self.random_str(30), self.random_str(30), key)
         cache_path = "%s/%s" % (self.cache_path_root, self.namespace)
 
         if not self._exist(file_path=cache_path):
             self.create_folder(folder_path=cache_path)
 
-        if not os.path.exists(os.path.dirname(local_path)):
-            bbcloud_python_sdk.make_dir(os.path.dirname(local_path))
+        if os.path.isfile(file_path):
+            new_file_path = os.path.join(os.path.dirname(file_path), key)
+            if file_path != new_file_path:
+                shutil.copyfile(file_path, new_file_path)
+            res = self.getFl().upload_file(dest_path=cache_path, file_path=new_file_path)
+
+            if file_path != new_file_path:
+                os.remove(new_file_path)
+
+            if del_local:
+                if os.path.exists(file_path):
+                    os.remove(file_path)
+        else:
+            if not os.path.exists(os.path.dirname(local_path)):
+                bbcloud_python_sdk.make_dir(os.path.dirname(local_path))
 
-        if file_path:
             if isinstance(file_path, str) and re.match("http", file_path) and file_path is not None:
                 bbcloud_python_sdk.download_file(file_path, local_path)
             elif isinstance(file_path, dict) or isinstance(file_path, list):
                 bbcloud_python_sdk.create_json_file(local_path, file_path)
             elif os.path.isdir(file_path):
                 bbcloud_python_sdk.zip_dirs(local_path, file_path)
-            elif os.path.isfile(file_path):
-                new_file_path = os.path.join(os.path.dirname(file_path), key)
-                local_path = new_file_path
             res = self.getFl().upload_file(dest_path=cache_path, file_path=local_path)
+
             logging.info(res)
             if del_local:
                 if os.path.exists(local_path):
                     os.remove(local_path)
-
+        logging.info(res)
     def get(self, key, local_file):
         """
         从群晖获取缓存文件
